#
# spec file for package python-dmidecode
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%define modname dmidecode
%{?sle15_python_module_pythons}
Name:           python-dmidecode
Version:        3.12.3+git.1676426290.4fdb678
Release:        1.0.2.1.sr20250402
Summary:        Python module to access DMI data
License:        GPL-2.0-only
Group:          System/Libraries
URL:            https://github.com/nima/python-dmidecode
# Source0:        https://github.com/nima/python-dmidecode/archive/refs/tags/v%%{version}.tar.gz#/python-dmidecode-%%{version}.tar.gz
Source0:        %{name}-%{version}.tar.gz
Source99:       python-dmidecode.rpmlintrc
# PATCH-FIX-UPSTREAM gcc7-inline.patch gh#nima/python-dmidecode#35 mcepl@suse.com
# Don't use inline keyword.
Patch1:         gcc7-inline.patch
# PATCH-FIX-UPSTREAM 31-version_info-v-version.patch gh#nima/python-dmidecode#31 mcepl@suse.com
# use sys.version_info instead of sys.version
Patch2:         31-version_info-v-version.patch
# PATCH-FIX-UPSTREAM detect-lib-with-py3.patch gh#nima/python-dmidecode#36 mcepl@suse.com
#  Make the code future-proof against removal of distutils module.
Patch3:         detect-lib-with-py3.patch
# PATCH-FIX-UPSTREAM gcc14.patch gh#nima/python-dmidecode#59 -- daniel.garcia@suse.com
Patch4:         gcc14.patch
# PATCH-FIX-OPENSUSE fix-loglevel.patch gh#nima/python-dmidecode#60
Patch5:         fix-loglevel.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libxml2-devel
BuildRequires:  python-rpm-macros
Requires:       python
Requires(post): update-alternatives
Requires(postun): update-alternatives
Obsoletes:      %{oldpython}-dmidecode <= %{version}
Obsoletes:      python-python-dmidecode <= %{version}
%if 0%{?sle_version} >= 150400 || 0%{?suse_version} >= 1550
BuildRequires:  %{python_module libxml2}
%else
BuildRequires:  python2-libxml2-python
BuildRequires:  python3-libxml2-python
%endif
%python_subpackages

%description
python-dmidecode is a python extension module that uses the code-base
of the 'dmidecode' utility, and presents the data as python data
structures or as XML data using libxml2.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
export CFLAGS="%{optflags}"
%{python_expand export LDFLAGS="-Wl,-rpath=%{$python_sitearch}"
%make_build PY_BIN=$python build
}

%install
%{python_expand rm -f %{buildroot}%{_datadir}/python-dmidecode/pymap.xml
$python src/setup.py install --root %{buildroot} --prefix=%{_prefix}

# prepare alternatives
install -d %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_datadir}/python-dmidecode/pymap{,-%{$python_bin_suffix}}.xml
touch %{buildroot}%{_sysconfdir}/alternatives/pymap.xml
ln -s %{_sysconfdir}/alternatives/pymap.xml \
      %{buildroot}%{_datadir}/python-dmidecode/pymap.xml
%fdupes %{buildroot}%{$python_sitearch}
}

%check
pushd unit-tests
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
%make_build PY_BIN=$python
}
popd

%post
PRIO=$(echo %{python_version}|tr -d '.')
%{_sbindir}/update-alternatives --install %{_datadir}/python-dmidecode/pymap.xml pymap.xml \
    %{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml ${PRIO}

%postun
if [ ! -f %{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml ] ; then
   MAJVER=$(ver=%{python_version}; echo ${ver:0:1})
   %{_sbindir}/update-alternatives --remove pymap.xml \
        %{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml
fi

%files %{python_files}
%license doc/LICENSE
%doc README doc/README.upstream doc/AUTHORS doc/AUTHORS.upstream
%dir %{_datadir}/python-dmidecode/
%ghost %{_sysconfdir}/alternatives/pymap.xml
%ghost %{_datadir}/python-dmidecode/pymap.xml
%{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml
# %%{python_sitearch}/python_dmidecode-%%{version}*-info
%{python_sitearch}/python_dmidecode-*-info
%{python_sitearch}/dmidecode.py
%{python_sitearch}/dmidecodemod.*.so
%pycache_only %{python_sitearch}/__pycache__/dmidecode*.pyc

%changelog
* Fri Apr 25 2025 mcepl@cepl.eu
- Update to version 3.12.2+git.1676426290.4fdb678:
  * Fix dmi_cache_size_2 will add unit twice.
  * v3.12.3
  * Add defined BIGENDIAN in types.h
  * Solve dmi_memory_device_extended_size WORD issue
  * Add bus address for type 09 in pymap.xml
* Mon Mar  3 2025 Daniel Garcia <daniel.garcia@suse.com>
- Add patch fix-loglevel.patch to fix invalid log level error.
  gh#nima/python-dmidecode#60 bsc#1237685
* Tue Oct 22 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add gcc14.patch to make it compatible with gcc14
  gh#nima/python-dmidecode#59
* Tue Feb 13 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add setuptools buildrequires, distutils is not part of python-base
  from python 3.12+
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Mar 14 2023 Matej Cepl <mcepl@suse.com>
- In the end just a cosmetical changes and cleaning up the SPEC
  file.
* Sat Nov 19 2022 Matej Cepl <mcepl@suse.com>
- Update to the upstream release 3.12.3:
  - consolidation of previous git commits
  - support SMBIOS3.3.0
- Remove upstreamed huge-memory.patch
* Wed Oct 26 2022 Matej Cepl <mcepl@suse.com>
- Modify detect-lib-with-py3.patch to be more robust.
* Wed Oct 26 2022 mcepl@cepl.eu
- Update to version 3.12.2+git.1666757106.e6ab5bc:
  * fix address_from_efi ret=0 message
  * fix function dmi_slot_segment_bus_func null point error in system slot
  * fix warning: this 'if' clause does not guard
  * fix warning: variable 'str_n' set but not used
  * fix warning: passing argument 2 of 'dmi_tpm_vendor_id' makes pointer from integer without a cast
  * fix warning: unused variable 'attr'
  * fix warning: unused variable 'addrstr'
  * fix warning: suggest parentheses around assignment used as truth value
  * fix warning: suggest parentheses around assignment used as truth value
  * src/dmidecode.c: In function 'dmi_tpm_characteristics': src/dmidecode.c:4788:24: warning: 'return' with a value, in function returning void [-Wreturn-type] 4788 | return data_n; | ^~~~~~
  * fix warning: passing argument 3 of 'dmi_slot_peers' from incompatible pointer type
  * fix warning: unused variable 'ver'
  * fix warning: variable 'eptype' set but not used
  * fix warning: suggest parentheses around '&&' within '||'
  * fix warning: comparison of integer expressions of different signedness
  * fix warning: ignoring return value of 'legacy_decode'
  * fix warning argument 1 null where non-null expected
  * Update python-dmidecode to smbios 3.3.0
  * Fix for printing an empty dictionary
  * Fix the failure of opening "/dev/mem": Permission denied
  * Fix bugs: 1. Fix smbios3_decode decoding sysfs table dump error. 2. Fix check smbios version error warning message.
  * Fix reading info permission deny bugs.
- Remove duplicated Makefile_libdir.patch.
* Mon Oct 17 2022 Matej Cepl <mcepl@suse.com>
- Add Makefile_libdir.patch to make package building even with
  faulty distutils.sysconfig (bsc#1204395).
* Fri May 20 2022 Matej Cepl <mcepl@suse.com>
- Synchronize SPEC file to be more like the SLE one.
* Mon Mar  7 2022 Matej Cepl <mcepl@suse.com>
- Add missing Obsoletes
* Fri Mar  4 2022 Matej Cepl <mcepl@suse.com>
- Harmonize Factory with the SLE version (update-alternatives
  instead of the subpackages).
* Mon Feb 28 2022 Matej Cepl <mcepl@suse.com>
- Add proper Provides/Obsoletes
* Thu Feb 24 2022 Matej Cepl <mcepl@suse.com>
- Cleanup multi-version builds.
* Thu Feb 24 2022 Matej Cepl <mcepl@suse.com>
- Introduce update-alternatives for
  /usr/share/python-dmidecode/pymap.xml.
* Thu Feb 24 2022 Matej Cepl <mcepl@suse.com>
- Fix package names.
* Sat Dec  4 2021 mcepl@cepl.eu
- Update to version 3.12.2+git.1625035095.f0a089a:
  * fix "src/dmidecodemodule.c:828:9 warning[-Wanalyzer-possible-null-argument]: use of possibly-NULL opt where non-null expected"
  * fix Error: FORWARD_NULL (CWE-476): [#def23]
  * fix "src/dmierror.c:55:9: warning[-Wanalyzer-possible-null-argument]: use of possibly-NULL buf where non-null expected"
  * fix Error: MISSING_COMMA: detected by covscan
  * fix Error: CONSTANT_EXPRESSION_RESULT detected by covscan
  * fix RESOURCE_LEAK error detected by covscan in src/util.c
  * fix RESOURCE_LEAK errors detected by covscan in src/xmlpythonizer.c
  * Update README
  * fix RESOURCE_LEAK errors detected by covscan in src/dmidecodemodule.c
  * Fixed memory Type Detail map size (bsc#1194351).
* Thu Dec  2 2021 Matej Cepl <mcepl@suse.com>
- Brutal simplification of the SPEC file to the standard single-spec
  Python one.
- Removal of support for Python 2 (bsc#1193262)
- Rename huge-memory.diff to huge-memory.patch (i.e., remove
  huge-memory.diff and add huge-memory.patch).
- Fix URL of Source0 (their own website is down, use GitHub
  release).
- Add 31-version_info-v-version.patch to make tests 3.10
  compatible.
* Thu Oct 19 2017 mc@suse.com
- build python2-dmidecode and use python-dmidecode for shared files
* Tue Oct 17 2017 mc@suse.com
- set rpath to libxml2mod library
* Sun Sep 24 2017 mc@suse.com
- version 3.12.2
- Add Python 3 subpackage
- Removed deprecated statements
* Wed May  3 2017 mantel@suse.de
- use correct data type DWORD for extended memory size (bsc#1036061)
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Fri Jan 17 2014 mc@suse.de
- version 3.12.1
  obsoleted patches (available in new upstream version):
  * python-dmidecode_copyright-update.patch
  * bug-713982_python-dmidecode-nullversion.patch
  * python-dmidecode-dmixml-error-63fa74b229dd2.patch
  * bug-823328-fix-set_vendor-segfault.dif
- Add SIGILL catcher in mem_chunk()
- Implemented dmixml_AddDMIstring()
- Harden dmi_string() calls with better NULL checks
- Do not add explictly 'dmispec' attributes inside switch()
  in dmi_decode()
- rebase against upstream dmidecode v2.12 and an update
  against the SMBIOS reference specification v2.8.0.
* Tue Jun 11 2013 mc@suse.de
- fix segfault in dmi_set_vendor (bnc#823328)
* Wed Sep 28 2011 mc@suse.de
- fix dmi_decode assertion during client registration
  (bnc#720885)
* Mon Sep 12 2011 mc@suse.de
- fix Segfault when decoding DMI data in dmi_processor_id()
  (bnc#713982)
* Thu Dec  9 2010 mc@suse.de
- initial release
